/// <reference types="node" />
import { DirectSecp256k1Wallet } from '@cosmjs/proto-signing';
/**
 * Registry account.
 */
export declare class Account {
    _privateKey: Buffer;
    _publicKey: Uint8Array;
    _encodedPubkey: string;
    _registryPublicKey: string;
    _wallet: DirectSecp256k1Wallet;
    _address: string;
    /**
     * Generate bip39 mnemonic.
     */
    static generateMnemonic(): string;
    /**
     * Generate private key from mnemonic.
     */
    static generateFromMnemonic(mnemonic: string): Promise<Account>;
    /**
     * New Account.
     */
    constructor(privateKey: Buffer);
    get privateKey(): Buffer;
    get encodedPubkey(): string;
    get registryPublicKey(): string;
    get address(): string;
    get wallet(): DirectSecp256k1Wallet;
    init(): Promise<void>;
    /**
     * Get private key.
     */
    getPrivateKey(): string;
    /**
     * Get record signature.
     */
    signRecord(record: any): Promise<Buffer>;
}
