import { StdFee } from '@cosmjs/stargate';
import { RegistryClient } from './registry-client';
import { Account } from './account';
import { MessageMsgAssociateBond, MessageMsgCancelBond, MessageMsgCreateBond, MessageMsgDissociateBond, MessageMsgDissociateRecords, MessageMsgReAssociateRecords, MessageMsgRefillBond, MessageMsgWithdrawBond } from './types/cerc/bond/message';
import { MessageMsgDeleteName, MessageMsgSetAuthorityBond, MessageMsgSetName } from './types/cerc/registry/message';
import { MessageMsgCommitBid, MessageMsgRevealBid } from './types/cerc/auction/message';
import { MessageMsgSendCoins } from './types/cosmos/bank/message';
import { MessageMsgOnboardParticipant } from './types/cerc/onboarding/message';
import { LaconicClient } from './laconic-client';
import { MsgCancelBondResponse, MsgCreateBondResponse, MsgRefillBondResponse, MsgWithdrawBondResponse } from './proto/cerc/bond/v1/tx';
import { MsgOnboardParticipantResponse } from './proto/cerc/onboarding/v1/tx';
import { MsgSendResponse } from './proto/cosmos/bank/v1beta1/tx';
export declare const DEFAULT_CHAIN_ID = "laconic_9000-1";
/**
 * Create an auction bid.
 */
export declare const createBid: (chainId: string, auctionId: string, bidderAddress: string, bidAmount: string, noise?: string) => Promise<{
    commitHash: string;
    reveal: {
        chainId: string;
        auctionId: string;
        bidderAddress: string;
        bidAmount: string;
        noise: string;
    };
    revealString: string;
}>;
export declare class Registry {
    _endpoints: {
        [key: string]: string;
    };
    _chainID: string;
    _client: RegistryClient;
    constructor(gqlUrl: string, rpcUrl?: string, chainId?: string);
    /**
     * Get accounts by addresses.
     */
    getAccounts(addresses: string[]): Promise<any>;
    get endpoints(): {
        [key: string]: string;
    };
    get chainID(): string;
    /**
     * Get server status.
     */
    getStatus(): Promise<any>;
    /**
     * Get records by ids.
     */
    getRecordsByIds(ids: string[], refs?: boolean): Promise<any>;
    /**
     * Get records by attributes.
     */
    queryRecords(attributes: {
        [key: string]: any;
    }, all?: boolean, refs?: boolean, limit?: number, offset?: number): Promise<any>;
    /**
     * Resolve names to records.
     */
    resolveNames(names: string[], refs?: boolean): Promise<any>;
    /**
     * Publish record.
     * @param transactionPrivateKey - private key in HEX to sign transaction.
     */
    setRecord({ privateKey, record, bondId }: {
        privateKey: string;
        record: any;
        bondId: string;
    }, transactionPrivateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgSetRecordResponse>;
    /**
     * Send coins.
     */
    sendCoins({ amount, denom, destinationAddress }: MessageMsgSendCoins, privateKey: string, fee: StdFee): Promise<MsgSendResponse>;
    /**
     * Computes the next bondId for the given account private key.
     */
    getNextBondId(privateKey: string): Promise<string>;
    /**
     * Get bonds by ids.
     */
    getBondsByIds(ids: string[]): Promise<any>;
    /**
     * Query bonds.
     */
    queryBonds(): Promise<any>;
    /**
   * Query bonds by owner(s).
   */
    queryBondsByOwner(owners: string[]): Promise<any>;
    /**
     * Create bond.
     */
    createBond({ denom, amount }: MessageMsgCreateBond, privateKey: string, fee: StdFee): Promise<MsgCreateBondResponse>;
    /**
     * Refill bond.
     */
    refillBond({ denom, amount, id }: MessageMsgRefillBond, privateKey: string, fee: StdFee): Promise<MsgRefillBondResponse>;
    /**
     * Withdraw (from) bond.
     */
    withdrawBond({ denom, amount, id }: MessageMsgWithdrawBond, privateKey: string, fee: StdFee): Promise<MsgWithdrawBondResponse>;
    /**
     * Cancel bond.
     */
    cancelBond({ id }: MessageMsgCancelBond, privateKey: string, fee: StdFee): Promise<MsgCancelBondResponse>;
    /**
     * Associate record with bond.
     */
    associateBond({ bondId, recordId }: MessageMsgAssociateBond, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgAssociateBondResponse>;
    /**
     * Dissociate record from bond.
     */
    dissociateBond({ recordId }: MessageMsgDissociateBond, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgDissociateBondResponse>;
    /**
     * Dissociate all records from bond.
     */
    dissociateRecords({ bondId }: MessageMsgDissociateRecords, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgDissociateRecordsResponse>;
    /**
     * Reassociate records (switch bond).
     */
    reassociateRecords({ newBondId, oldBondId }: MessageMsgReAssociateRecords, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgReassociateRecordsResponse>;
    /**
     * Reserve authority.
     */
    reserveAuthority({ name, owner }: {
        name: string;
        owner?: string;
    }, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgReserveAuthorityResponse>;
    /**
     * Set authority bond.
     */
    setAuthorityBond({ bondId, name }: MessageMsgSetAuthorityBond, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgSetAuthorityBondResponse>;
    /**
     * Commit auction bid.
     */
    commitBid({ auctionId, commitHash }: MessageMsgCommitBid, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/auction/v1/tx").MsgCommitBidResponse>;
    /**
     * Reveal auction bid.
     */
    revealBid({ auctionId, reveal }: MessageMsgRevealBid, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/auction/v1/tx").MsgRevealBidResponse>;
    /**
     * Get records by ids.
     */
    getAuctionsByIds(ids: string[]): Promise<any>;
    /**
     * List authorities by owner.
     */
    getAuthorities(owner?: string, auction?: boolean): Promise<any>;
    /**
     * Lookup authorities by names.
     */
    lookupAuthorities(names: string[], auction?: boolean): Promise<any>;
    /**
     * Set name (LRN) to record ID (CID).
     */
    setName({ cid, lrn }: MessageMsgSetName, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgSetNameResponse>;
    /**
     * Lookup naming information.
     */
    lookupNames(names: string[], history?: boolean): Promise<any>;
    /**
     * Delete name (LRN) mapping.
     */
    deleteName({ lrn }: MessageMsgDeleteName, privateKey: string, fee: StdFee): Promise<import("./proto/cerc/registry/v1/tx").MsgDeleteNameResponse>;
    getLaconicClient(account: Account): Promise<LaconicClient>;
    /**
     * Onboard participant.
    */
    onboardParticipant({ ethPayload, ethSignature, role, kycId }: MessageMsgOnboardParticipant, privateKey: string, fee: StdFee): Promise<MsgOnboardParticipantResponse>;
    /**
   * Query participants.
   */
    getParticipants(): Promise<any>;
    /**
     * Get participant by cosmos (laconic) address.
    */
    getParticipantByAddress(address: string): Promise<any>;
    /**
     * Get participant by nitro address.
    */
    getParticipantByNitroAddress(nitroAddress: string): Promise<any>;
}
export { Account };
export { LaconicClient };
export * from './types/cerc/bond/message';
export * from './types/cerc/onboarding/message';
