"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LaconicClient = exports.Account = exports.Registry = exports.createBid = exports.DEFAULT_CHAIN_ID = void 0;
const js_sha256_1 = require("js-sha256");
const registry_client_1 = require("./registry-client");
const account_1 = require("./account");
Object.defineProperty(exports, "Account", { enumerable: true, get: function () { return account_1.Account; } });
const util_1 = require("./util");
const laconic_client_1 = require("./laconic-client");
Object.defineProperty(exports, "LaconicClient", { enumerable: true, get: function () { return laconic_client_1.LaconicClient; } });
const coin_1 = require("./proto/cosmos/base/v1beta1/coin");
exports.DEFAULT_CHAIN_ID = 'laconic_9000-1';
/**
 * Create an auction bid.
 */
const createBid = (chainId, auctionId, bidderAddress, bidAmount, noise) => __awaiter(void 0, void 0, void 0, function* () {
    if (!noise) {
        noise = account_1.Account.generateMnemonic();
    }
    const reveal = {
        chainId,
        auctionId,
        bidderAddress,
        bidAmount,
        noise
    };
    const commitHash = yield util_1.Util.getContentId(reveal);
    const revealString = Buffer.from(JSON.stringify(reveal)).toString('hex');
    return {
        commitHash,
        reveal,
        revealString
    };
});
exports.createBid = createBid;
class Registry {
    constructor(gqlUrl, rpcUrl = '', chainId = exports.DEFAULT_CHAIN_ID) {
        this._endpoints = {
            rpc: rpcUrl,
            gql: gqlUrl
        };
        this._client = new registry_client_1.RegistryClient(gqlUrl, rpcUrl);
        this._chainID = chainId;
    }
    /**
     * Get accounts by addresses.
     */
    getAccounts(addresses) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getAccounts(addresses);
        });
    }
    get endpoints() {
        return this._endpoints;
    }
    get chainID() {
        return this._chainID;
    }
    /**
     * Get server status.
     */
    getStatus() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getStatus();
        });
    }
    /**
     * Get records by ids.
     */
    getRecordsByIds(ids, refs = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getRecordsByIds(ids, refs);
        });
    }
    /**
     * Get records by attributes.
     */
    queryRecords(attributes, all = false, refs = false, limit, offset) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.queryRecords(attributes, all, refs, limit, offset);
        });
    }
    /**
     * Resolve names to records.
     */
    resolveNames(names, refs = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.resolveNames(names, refs);
        });
    }
    /**
     * Publish record.
     * @param transactionPrivateKey - private key in HEX to sign transaction.
     */
    setRecord({ privateKey, record, bondId }, transactionPrivateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(transactionPrivateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.setRecord({ privateKey, record, bondId }, account.address, fee);
        });
    }
    /**
     * Send coins.
     */
    sendCoins({ amount, denom, destinationAddress }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            const response = yield laconicClient.sendTokens(account.address, destinationAddress, [
                coin_1.Coin.fromPartial({
                    denom,
                    amount
                })
            ], fee);
            return laconicClient.parseResponse(response);
        });
    }
    /**
     * Computes the next bondId for the given account private key.
     */
    getNextBondId(privateKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const accounts = yield this.getAccounts([account.address]);
            if (!accounts.length) {
                throw new Error('Account does not exist.');
            }
            const [accountObj] = accounts;
            const nextSeq = parseInt(accountObj.sequence, 10) + 1;
            result = (0, js_sha256_1.sha256)(`${accountObj.address}:${accountObj.number}:${nextSeq}`);
            return result;
        });
    }
    /**
     * Get bonds by ids.
     */
    getBondsByIds(ids) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getBondsByIds(ids);
        });
    }
    /**
     * Query bonds.
     */
    queryBonds() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.queryBonds();
        });
    }
    /**
   * Query bonds by owner(s).
   */
    queryBondsByOwner(owners) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.queryBondsByOwner(owners);
        });
    }
    /**
     * Create bond.
     */
    createBond({ denom, amount }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.createBond(account.address, denom, amount, fee);
        });
    }
    /**
     * Refill bond.
     */
    refillBond({ denom, amount, id }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.refillBond(account.address, denom, amount, id, fee);
        });
    }
    /**
     * Withdraw (from) bond.
     */
    withdrawBond({ denom, amount, id }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.withdrawBond(account.address, denom, amount, id, fee);
        });
    }
    /**
     * Cancel bond.
     */
    cancelBond({ id }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.cancelBond(account.address, id, fee);
        });
    }
    /**
     * Associate record with bond.
     */
    associateBond({ bondId, recordId }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.associateBond(account.address, recordId, bondId, fee);
        });
    }
    /**
     * Dissociate record from bond.
     */
    dissociateBond({ recordId }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.dissociateBond(account.address, recordId, fee);
        });
    }
    /**
     * Dissociate all records from bond.
     */
    dissociateRecords({ bondId }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.dissociateRecords(account.address, bondId, fee);
        });
    }
    /**
     * Reassociate records (switch bond).
     */
    reassociateRecords({ newBondId, oldBondId }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.reassociateRecords(account.address, oldBondId, newBondId, fee);
        });
    }
    /**
     * Reserve authority.
     */
    reserveAuthority({ name, owner }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.reserveAuthority(account.address, name, owner || account.address, fee);
        });
    }
    /**
     * Set authority bond.
     */
    setAuthorityBond({ bondId, name }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.setAuthorityBond(account.address, bondId, name, fee);
        });
    }
    /**
     * Commit auction bid.
     */
    commitBid({ auctionId, commitHash }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.commitBid(account.address, auctionId, commitHash, fee);
        });
    }
    /**
     * Reveal auction bid.
     */
    revealBid({ auctionId, reveal }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.revealBid(account.address, auctionId, reveal, fee);
        });
    }
    /**
     * Get records by ids.
     */
    getAuctionsByIds(ids) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getAuctionsByIds(ids);
        });
    }
    /**
     * List authorities by owner.
     */
    getAuthorities(owner, auction = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getAuthorities(owner, auction);
        });
    }
    /**
     * Lookup authorities by names.
     */
    lookupAuthorities(names, auction = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.lookupAuthorities(names, auction);
        });
    }
    /**
     * Set name (LRN) to record ID (CID).
     */
    setName({ cid, lrn }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.setName(account.address, lrn, cid, fee);
        });
    }
    /**
     * Lookup naming information.
     */
    lookupNames(names, history = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.lookupNames(names, history);
        });
    }
    /**
     * Delete name (LRN) mapping.
     */
    deleteName({ lrn }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.deleteName(account.address, lrn, fee);
        });
    }
    getLaconicClient(account) {
        return __awaiter(this, void 0, void 0, function* () {
            return laconic_client_1.LaconicClient.connectWithSigner(this._endpoints.rpc, account.wallet);
        });
    }
    /**
     * Onboard participant.
    */
    onboardParticipant({ ethPayload, ethSignature, role, kycId }, privateKey, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const account = new account_1.Account(Buffer.from(privateKey, 'hex'));
            yield account.init();
            const laconicClient = yield this.getLaconicClient(account);
            return laconicClient.onboardParticipant(account.address, ethPayload, ethSignature, role, kycId, fee);
        });
    }
    /**
   * Query participants.
   */
    getParticipants() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getParticipants();
        });
    }
    /**
     * Get participant by cosmos (laconic) address.
    */
    getParticipantByAddress(address) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getParticipantByAddress(address);
        });
    }
    /**
     * Get participant by nitro address.
    */
    getParticipantByNitroAddress(nitroAddress) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._client.getParticipantByNitroAddress(nitroAddress);
        });
    }
}
exports.Registry = Registry;
__exportStar(require("./types/cerc/bond/message"), exports);
__exportStar(require("./types/cerc/onboarding/message"), exports);
