import { Duration } from "../../../google/protobuf/duration";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import Long from "long";
import _m0 from "protobufjs/minimal";
export declare const protobufPackage = "cerc.auction.v1";
/** Params defines the auction module parameters */
export interface Params {
    /** Duration of the commits phase in seconds */
    commitsDuration?: Duration;
    /** Duration of the reveals phase in seconds */
    revealsDuration?: Duration;
    /** Commit fees */
    commitFee?: Coin;
    /** Reveal fees */
    revealFee?: Coin;
    /** Minimum acceptable bid amount */
    minimumBid?: Coin;
}
/** Auction represents a sealed-bid on-chain auction */
export interface Auction {
    id: string;
    status: string;
    /** Address of the creator of the auction */
    ownerAddress: string;
    /** Timestamp at which the auction was created */
    createTime?: Date;
    /** Timestamp at which the commits phase concluded */
    commitsEndTime?: Date;
    /** Timestamp at which the reveals phase concluded */
    revealsEndTime?: Date;
    /**
     * Commit and reveal fees must both be paid when committing a bid
     * Reveal fee is returned only if the bid is revealed
     */
    commitFee?: Coin;
    revealFee?: Coin;
    /** Minimum acceptable bid amount for a valid commit */
    minimumBid?: Coin;
    /** Address of the winner */
    winnerAddress: string;
    /** Winning bid, i.e., the highest bid */
    winningBid?: Coin;
    /** Amount the winner pays, i.e. the second highest auction */
    winningPrice?: Coin;
}
/** Auctions represent all the auctions in the module */
export interface Auctions {
    auctions: Auction[];
}
/** Bid represents a sealed bid (commit) made during the auction */
export interface Bid {
    auctionId: string;
    bidderAddress: string;
    status: string;
    commitHash: string;
    commitTime?: Date;
    commitFee?: Coin;
    revealTime?: Date;
    revealFee?: Coin;
    bidAmount?: Coin;
}
export declare const Params: {
    encode(message: Params, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): unknown;
    fromPartial<I extends {
        commitsDuration?: {
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } | undefined;
        revealsDuration?: {
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        minimumBid?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
    } & {
        commitsDuration?: ({
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } & {
            seconds?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K in Exclude<keyof I["commitsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
            nanos?: number | undefined;
        } & { [K_1 in Exclude<keyof I["commitsDuration"], keyof Duration>]: never; }) | undefined;
        revealsDuration?: ({
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } & {
            seconds?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K_2 in Exclude<keyof I["revealsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
            nanos?: number | undefined;
        } & { [K_3 in Exclude<keyof I["revealsDuration"], keyof Duration>]: never; }) | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_4 in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_5 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        minimumBid?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_6 in Exclude<keyof I["minimumBid"], keyof Coin>]: never; }) | undefined;
    } & { [K_7 in Exclude<keyof I, keyof Params>]: never; }>(object: I): Params;
};
export declare const Auction: {
    encode(message: Auction, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Auction;
    fromJSON(object: any): Auction;
    toJSON(message: Auction): unknown;
    fromPartial<I extends {
        id?: string | undefined;
        status?: string | undefined;
        ownerAddress?: string | undefined;
        createTime?: Date | undefined;
        commitsEndTime?: Date | undefined;
        revealsEndTime?: Date | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        minimumBid?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        winnerAddress?: string | undefined;
        winningBid?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        winningPrice?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
    } & {
        id?: string | undefined;
        status?: string | undefined;
        ownerAddress?: string | undefined;
        createTime?: Date | undefined;
        commitsEndTime?: Date | undefined;
        revealsEndTime?: Date | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_1 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        minimumBid?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_2 in Exclude<keyof I["minimumBid"], keyof Coin>]: never; }) | undefined;
        winnerAddress?: string | undefined;
        winningBid?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_3 in Exclude<keyof I["winningBid"], keyof Coin>]: never; }) | undefined;
        winningPrice?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_4 in Exclude<keyof I["winningPrice"], keyof Coin>]: never; }) | undefined;
    } & { [K_5 in Exclude<keyof I, keyof Auction>]: never; }>(object: I): Auction;
};
export declare const Auctions: {
    encode(message: Auctions, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Auctions;
    fromJSON(object: any): Auctions;
    toJSON(message: Auctions): unknown;
    fromPartial<I extends {
        auctions?: {
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[] | undefined;
    } & {
        auctions?: ({
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[] & ({
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auctions"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auctions"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auctions"][number]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddress?: string | undefined;
            winningBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_3 in Exclude<keyof I["auctions"][number]["winningBid"], keyof Coin>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auctions"][number]["winningPrice"], keyof Coin>]: never; }) | undefined;
        } & { [K_5 in Exclude<keyof I["auctions"][number], keyof Auction>]: never; })[] & { [K_6 in Exclude<keyof I["auctions"], keyof {
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[]>]: never; }) | undefined;
    } & { [K_7 in Exclude<keyof I, "auctions">]: never; }>(object: I): Auctions;
};
export declare const Bid: {
    encode(message: Bid, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Bid;
    fromJSON(object: any): Bid;
    toJSON(message: Bid): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        bidderAddress?: string | undefined;
        status?: string | undefined;
        commitHash?: string | undefined;
        commitTime?: Date | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealTime?: Date | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        bidAmount?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
    } & {
        auctionId?: string | undefined;
        bidderAddress?: string | undefined;
        status?: string | undefined;
        commitHash?: string | undefined;
        commitTime?: Date | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealTime?: Date | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_1 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        bidAmount?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_2 in Exclude<keyof I["bidAmount"], keyof Coin>]: never; }) | undefined;
    } & { [K_3 in Exclude<keyof I, keyof Bid>]: never; }>(object: I): Bid;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export {};
