import { Params, Auctions, Auction, Bid } from "./auction";
import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import Long from "long";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import _m0 from "protobufjs/minimal";
export declare const protobufPackage = "cerc.auction.v1";
/**
 * QueryParamsRequest is the format to query the parameters of the auction
 * module
 */
export interface QueryParamsRequest {
}
/** QueryParamsResponse returns parameters of the auction module */
export interface QueryParamsResponse {
    params?: Params;
}
/** AuctionsRequest is the format for querying all the auctions */
export interface QueryAuctionsRequest {
    /** pagination defines an optional pagination info for the next request */
    pagination?: PageRequest;
}
/** AuctionsResponse returns the list of all auctions */
export interface QueryAuctionsResponse {
    /** List of auctions */
    auctions?: Auctions;
    /** pagination defines an optional pagination info for the next request */
    pagination?: PageRequest;
}
/** AuctionRequest is the format for querying a specific auction */
export interface QueryGetAuctionRequest {
    /** Auction id */
    id: string;
}
/** AuctionResponse returns the details of the queried auction */
export interface QueryGetAuctionResponse {
    /** Auction details */
    auction?: Auction;
}
/** BidRequest is the format for querying a specific bid in an auction */
export interface QueryGetBidRequest {
    /** Auction id */
    auctionId: string;
    /** Bidder address */
    bidder: string;
}
/** BidResponse returns the details of the queried bid */
export interface QueryGetBidResponse {
    /** Bid details */
    bid?: Bid;
}
/** BidsRequest is the format for querying all bids in an auction */
export interface QueryGetBidsRequest {
    /** Auction id */
    auctionId: string;
}
/** BidsResponse returns details of all bids in an auction */
export interface QueryGetBidsResponse {
    /** List of bids in the auction */
    bids: Bid[];
}
/**
 * AuctionsByBidderRequest is the format for querying all auctions containing a
 * bidder address
 */
export interface QueryAuctionsByBidderRequest {
    /** Address of the bidder */
    bidderAddress: string;
}
/** AuctionsByBidderResponse returns all auctions containing a bidder */
export interface QueryAuctionsByBidderResponse {
    /** List of auctions */
    auctions?: Auctions;
}
/**
 * AuctionsByOwnerRequest is the format for querying all auctions created by an
 * owner
 */
export interface QueryAuctionsByOwnerRequest {
    /** Address of the owner */
    ownerAddress: string;
}
/** AuctionsByOwnerResponse returns all auctions created by an owner */
export interface QueryAuctionsByOwnerResponse {
    /** List of auctions */
    auctions?: Auctions;
}
/** BalanceRequest is the format to fetch all balances */
export interface QueryGetAuctionModuleBalanceRequest {
}
/**
 * QueryGetAuctionModuleBalanceResponse is the response type for auction module
 * balance rpc method
 */
export interface QueryGetAuctionModuleBalanceResponse {
    /** Set of all balances within the auction */
    balance: Coin[];
}
export declare const QueryParamsRequest: {
    encode(_: QueryParamsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryParamsRequest;
    fromJSON(_: any): QueryParamsRequest;
    toJSON(_: QueryParamsRequest): unknown;
    fromPartial<I extends {} & {} & { [K in Exclude<keyof I, never>]: never; }>(_: I): QueryParamsRequest;
};
export declare const QueryParamsResponse: {
    encode(message: QueryParamsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryParamsResponse;
    fromJSON(object: any): QueryParamsResponse;
    toJSON(message: QueryParamsResponse): unknown;
    fromPartial<I extends {
        params?: {
            commitsDuration?: {
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } | undefined;
            revealsDuration?: {
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } | undefined;
    } & {
        params?: ({
            commitsDuration?: {
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } | undefined;
            revealsDuration?: {
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            commitsDuration?: ({
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } & {
                seconds?: string | number | (Long.Long & {
                    high: number;
                    low: number;
                    unsigned: boolean;
                    add: (addend: string | number | Long.Long) => Long.Long;
                    and: (other: string | number | Long.Long) => Long.Long;
                    compare: (other: string | number | Long.Long) => number;
                    comp: (other: string | number | Long.Long) => number;
                    divide: (divisor: string | number | Long.Long) => Long.Long;
                    div: (divisor: string | number | Long.Long) => Long.Long;
                    equals: (other: string | number | Long.Long) => boolean;
                    eq: (other: string | number | Long.Long) => boolean;
                    getHighBits: () => number;
                    getHighBitsUnsigned: () => number;
                    getLowBits: () => number;
                    getLowBitsUnsigned: () => number;
                    getNumBitsAbs: () => number;
                    greaterThan: (other: string | number | Long.Long) => boolean;
                    gt: (other: string | number | Long.Long) => boolean;
                    greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                    gte: (other: string | number | Long.Long) => boolean;
                    isEven: () => boolean;
                    isNegative: () => boolean;
                    isOdd: () => boolean;
                    isPositive: () => boolean;
                    isZero: () => boolean;
                    lessThan: (other: string | number | Long.Long) => boolean;
                    lt: (other: string | number | Long.Long) => boolean;
                    lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                    lte: (other: string | number | Long.Long) => boolean;
                    modulo: (other: string | number | Long.Long) => Long.Long;
                    mod: (other: string | number | Long.Long) => Long.Long;
                    multiply: (multiplier: string | number | Long.Long) => Long.Long;
                    mul: (multiplier: string | number | Long.Long) => Long.Long;
                    negate: () => Long.Long;
                    neg: () => Long.Long;
                    not: () => Long.Long;
                    notEquals: (other: string | number | Long.Long) => boolean;
                    neq: (other: string | number | Long.Long) => boolean;
                    or: (other: string | number | Long.Long) => Long.Long;
                    shiftLeft: (numBits: number | Long.Long) => Long.Long;
                    shl: (numBits: number | Long.Long) => Long.Long;
                    shiftRight: (numBits: number | Long.Long) => Long.Long;
                    shr: (numBits: number | Long.Long) => Long.Long;
                    shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                    shru: (numBits: number | Long.Long) => Long.Long;
                    subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                    sub: (subtrahend: string | number | Long.Long) => Long.Long;
                    toInt: () => number;
                    toNumber: () => number;
                    toBytes: (le?: boolean | undefined) => number[];
                    toBytesLE: () => number[];
                    toBytesBE: () => number[];
                    toSigned: () => Long.Long;
                    toString: (radix?: number | undefined) => string;
                    toUnsigned: () => Long.Long;
                    xor: (other: string | number | Long.Long) => Long.Long;
                } & { [K in Exclude<keyof I["params"]["commitsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
                nanos?: number | undefined;
            } & { [K_1 in Exclude<keyof I["params"]["commitsDuration"], keyof import("../../../google/protobuf/duration").Duration>]: never; }) | undefined;
            revealsDuration?: ({
                seconds?: string | number | Long.Long | undefined;
                nanos?: number | undefined;
            } & {
                seconds?: string | number | (Long.Long & {
                    high: number;
                    low: number;
                    unsigned: boolean;
                    add: (addend: string | number | Long.Long) => Long.Long;
                    and: (other: string | number | Long.Long) => Long.Long;
                    compare: (other: string | number | Long.Long) => number;
                    comp: (other: string | number | Long.Long) => number;
                    divide: (divisor: string | number | Long.Long) => Long.Long;
                    div: (divisor: string | number | Long.Long) => Long.Long;
                    equals: (other: string | number | Long.Long) => boolean;
                    eq: (other: string | number | Long.Long) => boolean;
                    getHighBits: () => number;
                    getHighBitsUnsigned: () => number;
                    getLowBits: () => number;
                    getLowBitsUnsigned: () => number;
                    getNumBitsAbs: () => number;
                    greaterThan: (other: string | number | Long.Long) => boolean;
                    gt: (other: string | number | Long.Long) => boolean;
                    greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                    gte: (other: string | number | Long.Long) => boolean;
                    isEven: () => boolean;
                    isNegative: () => boolean;
                    isOdd: () => boolean;
                    isPositive: () => boolean;
                    isZero: () => boolean;
                    lessThan: (other: string | number | Long.Long) => boolean;
                    lt: (other: string | number | Long.Long) => boolean;
                    lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                    lte: (other: string | number | Long.Long) => boolean;
                    modulo: (other: string | number | Long.Long) => Long.Long;
                    mod: (other: string | number | Long.Long) => Long.Long;
                    multiply: (multiplier: string | number | Long.Long) => Long.Long;
                    mul: (multiplier: string | number | Long.Long) => Long.Long;
                    negate: () => Long.Long;
                    neg: () => Long.Long;
                    not: () => Long.Long;
                    notEquals: (other: string | number | Long.Long) => boolean;
                    neq: (other: string | number | Long.Long) => boolean;
                    or: (other: string | number | Long.Long) => Long.Long;
                    shiftLeft: (numBits: number | Long.Long) => Long.Long;
                    shl: (numBits: number | Long.Long) => Long.Long;
                    shiftRight: (numBits: number | Long.Long) => Long.Long;
                    shr: (numBits: number | Long.Long) => Long.Long;
                    shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                    shru: (numBits: number | Long.Long) => Long.Long;
                    subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                    sub: (subtrahend: string | number | Long.Long) => Long.Long;
                    toInt: () => number;
                    toNumber: () => number;
                    toBytes: (le?: boolean | undefined) => number[];
                    toBytesLE: () => number[];
                    toBytesBE: () => number[];
                    toSigned: () => Long.Long;
                    toString: (radix?: number | undefined) => string;
                    toUnsigned: () => Long.Long;
                    xor: (other: string | number | Long.Long) => Long.Long;
                } & { [K_2 in Exclude<keyof I["params"]["revealsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
                nanos?: number | undefined;
            } & { [K_3 in Exclude<keyof I["params"]["revealsDuration"], keyof import("../../../google/protobuf/duration").Duration>]: never; }) | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["params"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_5 in Exclude<keyof I["params"]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_6 in Exclude<keyof I["params"]["minimumBid"], keyof Coin>]: never; }) | undefined;
        } & { [K_7 in Exclude<keyof I["params"], keyof Params>]: never; }) | undefined;
    } & { [K_8 in Exclude<keyof I, "params">]: never; }>(object: I): QueryParamsResponse;
};
export declare const QueryAuctionsRequest: {
    encode(message: QueryAuctionsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsRequest;
    fromJSON(object: any): QueryAuctionsRequest;
    toJSON(message: QueryAuctionsRequest): unknown;
    fromPartial<I extends {
        pagination?: {
            key?: Uint8Array | undefined;
            offset?: string | number | Long.Long | undefined;
            limit?: string | number | Long.Long | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } | undefined;
    } & {
        pagination?: ({
            key?: Uint8Array | undefined;
            offset?: string | number | Long.Long | undefined;
            limit?: string | number | Long.Long | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } & {
            key?: Uint8Array | undefined;
            offset?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K in Exclude<keyof I["pagination"]["offset"], keyof Long.Long>]: never; }) | undefined;
            limit?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K_1 in Exclude<keyof I["pagination"]["limit"], keyof Long.Long>]: never; }) | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } & { [K_2 in Exclude<keyof I["pagination"], keyof PageRequest>]: never; }) | undefined;
    } & { [K_3 in Exclude<keyof I, "pagination">]: never; }>(object: I): QueryAuctionsRequest;
};
export declare const QueryAuctionsResponse: {
    encode(message: QueryAuctionsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsResponse;
    fromJSON(object: any): QueryAuctionsResponse;
    toJSON(message: QueryAuctionsResponse): unknown;
    fromPartial<I extends {
        auctions?: {
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
        pagination?: {
            key?: Uint8Array | undefined;
            offset?: string | number | Long.Long | undefined;
            limit?: string | number | Long.Long | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } | undefined;
    } & {
        auctions?: ({
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } & {
            auctions?: ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] & ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            } & {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K in Exclude<keyof I["auctions"]["auctions"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
                revealFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_1 in Exclude<keyof I["auctions"]["auctions"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
                minimumBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_2 in Exclude<keyof I["auctions"]["auctions"][number]["minimumBid"], keyof Coin>]: never; }) | undefined;
                winnerAddress?: string | undefined;
                winningBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_3 in Exclude<keyof I["auctions"]["auctions"][number]["winningBid"], keyof Coin>]: never; }) | undefined;
                winningPrice?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_4 in Exclude<keyof I["auctions"]["auctions"][number]["winningPrice"], keyof Coin>]: never; }) | undefined;
            } & { [K_5 in Exclude<keyof I["auctions"]["auctions"][number], keyof Auction>]: never; })[] & { [K_6 in Exclude<keyof I["auctions"]["auctions"], keyof {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[]>]: never; }) | undefined;
        } & { [K_7 in Exclude<keyof I["auctions"], "auctions">]: never; }) | undefined;
        pagination?: ({
            key?: Uint8Array | undefined;
            offset?: string | number | Long.Long | undefined;
            limit?: string | number | Long.Long | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } & {
            key?: Uint8Array | undefined;
            offset?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K_8 in Exclude<keyof I["pagination"]["offset"], keyof Long.Long>]: never; }) | undefined;
            limit?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K_9 in Exclude<keyof I["pagination"]["limit"], keyof Long.Long>]: never; }) | undefined;
            countTotal?: boolean | undefined;
            reverse?: boolean | undefined;
        } & { [K_10 in Exclude<keyof I["pagination"], keyof PageRequest>]: never; }) | undefined;
    } & { [K_11 in Exclude<keyof I, keyof QueryAuctionsResponse>]: never; }>(object: I): QueryAuctionsResponse;
};
export declare const QueryGetAuctionRequest: {
    encode(message: QueryGetAuctionRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetAuctionRequest;
    fromJSON(object: any): QueryGetAuctionRequest;
    toJSON(message: QueryGetAuctionRequest): unknown;
    fromPartial<I extends {
        id?: string | undefined;
    } & {
        id?: string | undefined;
    } & { [K in Exclude<keyof I, "id">]: never; }>(object: I): QueryGetAuctionRequest;
};
export declare const QueryGetAuctionResponse: {
    encode(message: QueryGetAuctionResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetAuctionResponse;
    fromJSON(object: any): QueryGetAuctionResponse;
    toJSON(message: QueryGetAuctionResponse): unknown;
    fromPartial<I extends {
        auction?: {
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } | undefined;
    } & {
        auction?: ({
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddress?: string | undefined;
            winningBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            id?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auction"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auction"]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auction"]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddress?: string | undefined;
            winningBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_3 in Exclude<keyof I["auction"]["winningBid"], keyof Coin>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auction"]["winningPrice"], keyof Coin>]: never; }) | undefined;
        } & { [K_5 in Exclude<keyof I["auction"], keyof Auction>]: never; }) | undefined;
    } & { [K_6 in Exclude<keyof I, "auction">]: never; }>(object: I): QueryGetAuctionResponse;
};
export declare const QueryGetBidRequest: {
    encode(message: QueryGetBidRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetBidRequest;
    fromJSON(object: any): QueryGetBidRequest;
    toJSON(message: QueryGetBidRequest): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        bidder?: string | undefined;
    } & {
        auctionId?: string | undefined;
        bidder?: string | undefined;
    } & { [K in Exclude<keyof I, keyof QueryGetBidRequest>]: never; }>(object: I): QueryGetBidRequest;
};
export declare const QueryGetBidResponse: {
    encode(message: QueryGetBidResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetBidResponse;
    fromJSON(object: any): QueryGetBidResponse;
    toJSON(message: QueryGetBidResponse): unknown;
    fromPartial<I extends {
        bid?: {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } | undefined;
    } & {
        bid?: ({
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["bid"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealTime?: Date | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["bid"]["revealFee"], keyof Coin>]: never; }) | undefined;
            bidAmount?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["bid"]["bidAmount"], keyof Coin>]: never; }) | undefined;
        } & { [K_3 in Exclude<keyof I["bid"], keyof Bid>]: never; }) | undefined;
    } & { [K_4 in Exclude<keyof I, "bid">]: never; }>(object: I): QueryGetBidResponse;
};
export declare const QueryGetBidsRequest: {
    encode(message: QueryGetBidsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetBidsRequest;
    fromJSON(object: any): QueryGetBidsRequest;
    toJSON(message: QueryGetBidsRequest): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
    } & {
        auctionId?: string | undefined;
    } & { [K in Exclude<keyof I, "auctionId">]: never; }>(object: I): QueryGetBidsRequest;
};
export declare const QueryGetBidsResponse: {
    encode(message: QueryGetBidsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetBidsResponse;
    fromJSON(object: any): QueryGetBidsResponse;
    toJSON(message: QueryGetBidsResponse): unknown;
    fromPartial<I extends {
        bids?: {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[] | undefined;
    } & {
        bids?: ({
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[] & ({
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["bids"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealTime?: Date | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["bids"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
            bidAmount?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["bids"][number]["bidAmount"], keyof Coin>]: never; }) | undefined;
        } & { [K_3 in Exclude<keyof I["bids"][number], keyof Bid>]: never; })[] & { [K_4 in Exclude<keyof I["bids"], keyof {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        }[]>]: never; }) | undefined;
    } & { [K_5 in Exclude<keyof I, "bids">]: never; }>(object: I): QueryGetBidsResponse;
};
export declare const QueryAuctionsByBidderRequest: {
    encode(message: QueryAuctionsByBidderRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsByBidderRequest;
    fromJSON(object: any): QueryAuctionsByBidderRequest;
    toJSON(message: QueryAuctionsByBidderRequest): unknown;
    fromPartial<I extends {
        bidderAddress?: string | undefined;
    } & {
        bidderAddress?: string | undefined;
    } & { [K in Exclude<keyof I, "bidderAddress">]: never; }>(object: I): QueryAuctionsByBidderRequest;
};
export declare const QueryAuctionsByBidderResponse: {
    encode(message: QueryAuctionsByBidderResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsByBidderResponse;
    fromJSON(object: any): QueryAuctionsByBidderResponse;
    toJSON(message: QueryAuctionsByBidderResponse): unknown;
    fromPartial<I extends {
        auctions?: {
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
    } & {
        auctions?: ({
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } & {
            auctions?: ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] & ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            } & {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K in Exclude<keyof I["auctions"]["auctions"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
                revealFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_1 in Exclude<keyof I["auctions"]["auctions"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
                minimumBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_2 in Exclude<keyof I["auctions"]["auctions"][number]["minimumBid"], keyof Coin>]: never; }) | undefined;
                winnerAddress?: string | undefined;
                winningBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_3 in Exclude<keyof I["auctions"]["auctions"][number]["winningBid"], keyof Coin>]: never; }) | undefined;
                winningPrice?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_4 in Exclude<keyof I["auctions"]["auctions"][number]["winningPrice"], keyof Coin>]: never; }) | undefined;
            } & { [K_5 in Exclude<keyof I["auctions"]["auctions"][number], keyof Auction>]: never; })[] & { [K_6 in Exclude<keyof I["auctions"]["auctions"], keyof {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[]>]: never; }) | undefined;
        } & { [K_7 in Exclude<keyof I["auctions"], "auctions">]: never; }) | undefined;
    } & { [K_8 in Exclude<keyof I, "auctions">]: never; }>(object: I): QueryAuctionsByBidderResponse;
};
export declare const QueryAuctionsByOwnerRequest: {
    encode(message: QueryAuctionsByOwnerRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsByOwnerRequest;
    fromJSON(object: any): QueryAuctionsByOwnerRequest;
    toJSON(message: QueryAuctionsByOwnerRequest): unknown;
    fromPartial<I extends {
        ownerAddress?: string | undefined;
    } & {
        ownerAddress?: string | undefined;
    } & { [K in Exclude<keyof I, "ownerAddress">]: never; }>(object: I): QueryAuctionsByOwnerRequest;
};
export declare const QueryAuctionsByOwnerResponse: {
    encode(message: QueryAuctionsByOwnerResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryAuctionsByOwnerResponse;
    fromJSON(object: any): QueryAuctionsByOwnerResponse;
    toJSON(message: QueryAuctionsByOwnerResponse): unknown;
    fromPartial<I extends {
        auctions?: {
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
    } & {
        auctions?: ({
            auctions?: {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] | undefined;
        } & {
            auctions?: ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[] & ({
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            } & {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K in Exclude<keyof I["auctions"]["auctions"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
                revealFee?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_1 in Exclude<keyof I["auctions"]["auctions"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
                minimumBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_2 in Exclude<keyof I["auctions"]["auctions"][number]["minimumBid"], keyof Coin>]: never; }) | undefined;
                winnerAddress?: string | undefined;
                winningBid?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_3 in Exclude<keyof I["auctions"]["auctions"][number]["winningBid"], keyof Coin>]: never; }) | undefined;
                winningPrice?: ({
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } & { [K_4 in Exclude<keyof I["auctions"]["auctions"][number]["winningPrice"], keyof Coin>]: never; }) | undefined;
            } & { [K_5 in Exclude<keyof I["auctions"]["auctions"][number], keyof Auction>]: never; })[] & { [K_6 in Exclude<keyof I["auctions"]["auctions"], keyof {
                id?: string | undefined;
                status?: string | undefined;
                ownerAddress?: string | undefined;
                createTime?: Date | undefined;
                commitsEndTime?: Date | undefined;
                revealsEndTime?: Date | undefined;
                commitFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                revealFee?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                minimumBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winnerAddress?: string | undefined;
                winningBid?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
                winningPrice?: {
                    denom?: string | undefined;
                    amount?: string | undefined;
                } | undefined;
            }[]>]: never; }) | undefined;
        } & { [K_7 in Exclude<keyof I["auctions"], "auctions">]: never; }) | undefined;
    } & { [K_8 in Exclude<keyof I, "auctions">]: never; }>(object: I): QueryAuctionsByOwnerResponse;
};
export declare const QueryGetAuctionModuleBalanceRequest: {
    encode(_: QueryGetAuctionModuleBalanceRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetAuctionModuleBalanceRequest;
    fromJSON(_: any): QueryGetAuctionModuleBalanceRequest;
    toJSON(_: QueryGetAuctionModuleBalanceRequest): unknown;
    fromPartial<I extends {} & {} & { [K in Exclude<keyof I, never>]: never; }>(_: I): QueryGetAuctionModuleBalanceRequest;
};
export declare const QueryGetAuctionModuleBalanceResponse: {
    encode(message: QueryGetAuctionModuleBalanceResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryGetAuctionModuleBalanceResponse;
    fromJSON(object: any): QueryGetAuctionModuleBalanceResponse;
    toJSON(message: QueryGetAuctionModuleBalanceResponse): unknown;
    fromPartial<I extends {
        balance?: {
            denom?: string | undefined;
            amount?: string | undefined;
        }[] | undefined;
    } & {
        balance?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        }[] & ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K in Exclude<keyof I["balance"][number], keyof Coin>]: never; })[] & { [K_1 in Exclude<keyof I["balance"], keyof {
            denom?: string | undefined;
            amount?: string | undefined;
        }[]>]: never; }) | undefined;
    } & { [K_2 in Exclude<keyof I, "balance">]: never; }>(object: I): QueryGetAuctionModuleBalanceResponse;
};
/** Query defines the gRPC querier interface for the auction module */
export interface Query {
    /** Params queries auction module params */
    Params(request: QueryParamsRequest): Promise<QueryParamsResponse>;
    /** Auctions queries all auctions */
    Auctions(request: QueryAuctionsRequest): Promise<QueryAuctionsResponse>;
    /** GetAuction queries an auction */
    GetAuction(request: QueryGetAuctionRequest): Promise<QueryGetAuctionResponse>;
    /** GetBid queries an auction bid */
    GetBid(request: QueryGetBidRequest): Promise<QueryGetBidResponse>;
    /** GetBids queries all auction bids */
    GetBids(request: QueryGetBidsRequest): Promise<QueryGetBidsResponse>;
    /** AuctionsByBidder queries auctions by bidder */
    AuctionsByBidder(request: QueryAuctionsByBidderRequest): Promise<QueryAuctionsByBidderResponse>;
    /** AuctionsByOwner queries auctions by owner */
    AuctionsByOwner(request: QueryAuctionsByOwnerRequest): Promise<QueryAuctionsByOwnerResponse>;
    /** GetAuctionModuleBalance queries the auction module account balance */
    GetAuctionModuleBalance(request: QueryGetAuctionModuleBalanceRequest): Promise<QueryGetAuctionModuleBalanceResponse>;
}
export declare class QueryClientImpl implements Query {
    private readonly rpc;
    constructor(rpc: Rpc);
    Params(request: QueryParamsRequest): Promise<QueryParamsResponse>;
    Auctions(request: QueryAuctionsRequest): Promise<QueryAuctionsResponse>;
    GetAuction(request: QueryGetAuctionRequest): Promise<QueryGetAuctionResponse>;
    GetBid(request: QueryGetBidRequest): Promise<QueryGetBidResponse>;
    GetBids(request: QueryGetBidsRequest): Promise<QueryGetBidsResponse>;
    AuctionsByBidder(request: QueryAuctionsByBidderRequest): Promise<QueryAuctionsByBidderResponse>;
    AuctionsByOwner(request: QueryAuctionsByOwnerRequest): Promise<QueryAuctionsByOwnerResponse>;
    GetAuctionModuleBalance(request: QueryGetAuctionModuleBalanceRequest): Promise<QueryGetAuctionModuleBalanceResponse>;
}
interface Rpc {
    request(service: string, method: string, data: Uint8Array): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export {};
