"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Util = void 0;
const Block = __importStar(require("multiformats/block"));
const sha2_1 = require("multiformats/hashes/sha2");
const dagCBOR = __importStar(require("@ipld/dag-cbor"));
const dagJSON = __importStar(require("@ipld/dag-json"));
/**
 * Utils
 */
class Util {
    /**
     * Sorts JSON object.
     */
    static sortJSON(obj) {
        if (obj instanceof Array) {
            for (let i = 0; i < obj.length; i++) {
                obj[i] = Util.sortJSON(obj[i]);
            }
            return obj;
        }
        if (typeof obj !== 'object' || obj === null)
            return obj;
        let keys = Object.keys(obj);
        keys = keys.sort();
        const newObject = {};
        for (let i = 0; i < keys.length; i++) {
            newObject[keys[i]] = Util.sortJSON(obj[keys[i]]);
        }
        return newObject;
    }
    /**
     * Marshal object into gql 'attributes' variable.
     */
    static toGQLAttributes(obj) {
        const vars = [];
        Object.keys(obj).forEach(key => {
            const value = this.toGQLValue(obj[key]);
            if (value !== undefined) {
                vars.push({ key, value });
            }
        });
        return vars;
    }
    static toGQLValue(obj) {
        if (obj === null) {
            return null;
        }
        let type = typeof obj;
        switch (type) {
            case 'number':
                type = (obj % 1 === 0) ? 'int' : 'float';
                return { [type]: obj };
            case 'string':
                return { string: obj };
            case 'boolean':
                return { boolean: obj };
            case 'object':
                if (obj['/'] !== undefined) {
                    return { link: obj['/'] };
                }
                if (obj instanceof Array) {
                    return { array: obj };
                }
                return { map: obj };
            case 'undefined':
                return undefined;
            default:
                throw new Error(`Unknown object type '${type}': ${obj}`);
        }
    }
    /**
     * Unmarshal attributes array to object.
     */
    static fromGQLAttributes(attributes = []) {
        const res = {};
        attributes.forEach(attr => {
            res[attr.key] = (attr.value === null) ? null : this.fromGQLValue(attr.value);
        });
        return res;
    }
    static fromGQLValue(obj) {
        // Get first non-null key
        const present = Object.keys(obj).find(k => obj[k] !== null);
        if (present === undefined) {
            throw new Error('Object has no non-null values');
        }
        // Create an array if array type attribute
        if (present === 'array') {
            return obj[present].map((e) => {
                return this.fromGQLValue(e);
            });
        }
        return obj[present];
    }
    /**
     * Get record content ID.
     */
    static getContentId(record) {
        return __awaiter(this, void 0, void 0, function* () {
            const serialized = dagJSON.encode(record);
            const recordData = dagJSON.decode(serialized);
            const block = yield Block.encode({
                value: recordData,
                codec: dagCBOR,
                hasher: sha2_1.sha256
            });
            return block.cid.toString();
        });
    }
}
exports.Util = Util;
